compressor

package
v0.0.0-...-276c624 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 16, 2023 License: MIT Imports: 4 Imported by: 11

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Bytes

func Bytes(b []byte) []byte

Bytes is shorthand for declaring a new default compressor instance, used to immediately compress a byte slice.

func String

func String(s string) string

String is shorthand for declaring a new default compressor instance, used to immediately compress a string.

Types

type Writer

type Writer struct {
	Forward io.Writer
	// contains filtered or unexported fields
}

func (*Writer) Close

func (w *Writer) Close() error

Close finishes the compression operation. Always call it before trying to retrieve the final result.

func (*Writer) ResetAnsi

func (w *Writer) ResetAnsi()

func (*Writer) Write

func (w *Writer) Write(b []byte) (int, error)

Write is used to write content to the ANSI buffer.

Jump to