package
Version:
v0.0.0-...-276c624
Opens a new window with list of versions in this module.
Published: Mar 16, 2023
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 11
Opens a new window with list of known importers.
Documentation
¶
Bytes is shorthand for declaring a new default compressor instance,
used to immediately compress a byte slice.
String is shorthand for declaring a new default compressor instance,
used to immediately compress a string.
type Writer struct {
Forward io.Writer
}
Close finishes the compression operation. Always call it before trying to
retrieve the final result.
Write is used to write content to the ANSI buffer.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.